@@ -5,7 +5,7 @@ use BSD::Sysctl qw( sysctl sysctl_exists );
 use Exporter ();
 use Carp qw( croak );
 
-$VERSION = '0.69_07';
+$VERSION = '0.69_10';
 @ISA     = qw( Exporter );
 @EXPORT  = qw( fsysctl nsysctl );
 
@@ -18,8 +18,8 @@ sub fsysctl {
 
 sub nsysctl {
     my $key = shift || croak "Key is missing";
-    #return if ! sysctl_exists($key);
-    #return sysctl($key);
+    return if ! sysctl_exists($key);
+    return sysctl($key);
 }
 
 1;
@@ -63,7 +63,7 @@ Copyright 2009 Burak Gürsoy. All rights reserved.
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.8.8 or, 
+it under the same terms as Perl itself, either Perl version 5.10.0 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
